=========
pymobi
=========
Mobipocket tools for **unpack** and **removesrcs**.

.. note::

    No removing **DRM**


Kindle Mobipocket format is private for AMAZON_, but some superman have parsed many parameter. You may find it from `Mobipocket Wiki`_

.. _`Mobipocket Wiki`: http//wiki.mobileread.com/wiki/MOBI
.. _`AMAZON`: http://www.amazon.com

Feature
-------
+ unpack mobi file into html, css and image file.
+ strip *SOURCE* section for package generated by ``kindlegen``
+ add book title before filename
+ ...

License
--------
Please follow GPLv3
